@@ -21,17 +21,13 @@
 #
 # ---------------------------------------------------------------------------##
 
-# imports
-from six.moves import range, tkinter
-
-# PySol imports
-from pysollib.mygettext import _
 from pysollib.mfxutil import KwStruct
-
-# Toolkit imports
+from pysollib.mygettext import _
 from pysollib.tk.basetkmfxdialog import BaseTkMfxDialog
 from pysollib.ui.tktile.solverdialog import BaseSolverDialog, solver_dialog
 
+from six.moves import range, tkinter
+
 # ************************************************************************
 # *
 # ************************************************************************
@@ -57,6 +53,7 @@ class SolverDialog(BaseSolverDialog, BaseTkMfxDialog):
         var.set('none')
         om = tkinter.OptionMenu(frame, var, *(self.presets))
         om.grid(row=row, column=1, sticky='ew', padx=2, pady=2)
+        var.trace('w', self._OnAssignToPreset)
         return var
 
     def _createShowProgressButton(self, frame):
